telega/models/message_entity

Types

pub type MessageEntity {
  MessageEntity(
    entity_type: String,
    offset: Int,
    length: Int,
    url: Option(String),
    user: Option(User),
    language: Option(String),
    custom_emoji_id: Option(String),
  )
}

Constructors

  • MessageEntity(
      entity_type: String,
      offset: Int,
      length: Int,
      url: Option(String),
      user: Option(User),
      language: Option(String),
      custom_emoji_id: Option(String),
    )

    Official reference: https://core.telegram.org/bots/api#messageentity

    Arguments

    • entity_type

      Type of the entity. Currently, can be “mention” (@username), “hashtag” (#hashtag), “cashtag” ($USD), “bot_command” (/start@jobs_bot), “url” (https://telegram.org), “email” (do-not-reply@telegram.org), “phone_number” (+1-212-555-0123), “bold” (bold text), “italic” (italic text), “underline” (underlined text), “strikethrough” (strikethrough text), “spoiler” (spoiler message), “blockquote” (block quotation), “code” (monowidth string), “pre” (monowidth block), “text_link” (for clickable text URLs), “text_mention” (for users without usernames), “custom_emoji” (for inline custom emoji stickers)

    • offset

      Offset in UTF-16 code units to the start of the entity

    • length

      Length of the entity in UTF-16 code units

    • url

      For “text_link” only, URL that will be opened after user taps on the text

    • user

      For “text_mention” only, the mentioned user

    • language

      For “pre” only, the programming language of the entity text

    • custom_emoji_id

      For “custom_emoji” only, unique identifier of the custom emoji. Use getCustomEmojiStickers to get full information about the sticker

Functions

pub fn decode(
  json: Dynamic,
) -> Result(MessageEntity, List(DecodeError))

Type of the entity. Currently, can be “mention” (@username), “hashtag” (#hashtag), “cashtag” ($USD), “bot_command” (/start@jobs_bot), “url” (https://telegram.org), “email” (do-not-reply@telegram.org), “phone_number” (+1-212-555-0123), “bold” (bold text), “italic” (italic text), “underline” (underlined text), “strikethrough” (strikethrough text), “spoiler” (spoiler message), “blockquote” (block quotation), “code” (monowidth string), “pre” (monowidth block), “text_link” (for clickable text URLs), “text_mention” (for users without usernames), “custom_emoji” (for inline custom emoji stickers) Offset in UTF-16 code units to the start of the entity Length of the entity in UTF-16 code units For “text_link” only, URL that will be opened after user taps on the text For “text_mention” only, the mentioned user For “pre” only, the programming language of the entity text For “custom_emoji” only, unique identifier of the custom emoji. Use getCustomEmojiStickers to get full information about the sticker

pub fn encode(message_entity: MessageEntity) -> Json
Search Document