telega/models/dice
Types
pub type SendDiceParameters {
SendDiceParameters(
chat_id: Int,
message_thread_id: Option(Int),
emoji: Option(String),
disable_notification: Option(Bool),
protect_content: Option(Bool),
reply_parameters: Option(ReplyParameters),
)
}
Constructors
-
SendDiceParameters( chat_id: Int, message_thread_id: Option(Int), emoji: Option(String), disable_notification: Option(Bool), protect_content: Option(Bool), reply_parameters: Option(ReplyParameters), )Arguments
-
message_thread_id
Unique identifier for the target message thread (topic) of the forum; for forum supergroups only
-
emoji
Emoji on which the dice throw animation is based. Currently, must be one of โ๐ฒโ, โ๐ฏโ, โ๐โ, โโฝโ, โ๐ณโ, or โ๐ฐโ. Dice can have values 1-6 for โ๐ฒโ, โ๐ฏโ and โ๐ณโ, values 1-5 for โ๐โ and โโฝโ, and values 1-64 for โ๐ฐโ. Defaults to โ๐ฒโ
-
disable_notification
Sends the message silently. Users will receive a notification with no sound.
-
protect_content
Protects the contents of the sent message from forwarding
-
reply_parameters
Description of the message to reply to
-
Functions
pub fn encode_send_dice_parameters(
params: SendDiceParameters,
) -> Json
pub fn new_send_dice_parameters(
chat_id chat_id: Int,
) -> SendDiceParameters
Unique identifier for the target message thread (topic) of the forum; for forum supergroups only Emoji on which the dice throw animation is based. Currently, must be one of โ๐ฒโ, โ๐ฏโ, โ๐โ, โโฝโ, โ๐ณโ, or โ๐ฐโ. Dice can have values 1-6 for โ๐ฒโ, โ๐ฏโ and โ๐ณโ, values 1-5 for โ๐โ and โโฝโ, and values 1-64 for โ๐ฐโ. Defaults to โ๐ฒโ Sends the message silently. Users will receive a notification with no sound. Protects the contents of the sent message from forwarding Description of the message to reply to